<?php

namespace Drupal\pagedesigner_responsive_images\Plugin\pagedesigner\Handler;

use Drupal\pagedesigner\Entity\Element;
use Drupal\pagedesigner_gallery\Plugin\pagedesigner\Handler\GalleryGallery;
use Drupal\pagedesigner_media\Plugin\MediaFieldHandlerBase;
use Drupal\ui_patterns\Definition\PatternDefinitionField;

/**
 * Process entities of type "gallery_gallery".
 *
 * @PagedesignerHandler(
 *   id = "responsive_image_gallery_gallery",
 *   name = @Translation("gallery handler"),
 *   types = {
 *      "gallery_gallery",
 *   },
 * )
 */
class ResponsiveImageGalleryGallery extends GalleryGallery {

  /**
   * {@inheritdoc}
   */
  public function collectAttachments(array &$attachments) {
  }

  /**
   * {@inheritdoc}
   */
  public function collectPatterns(array &$patterns) {
  }

  /**
   * {@inheritdoc}
   */
  public function adaptPatterns(array &$patterns) {
  }

  /**
   * {@inheritdoc}
   */
  public function prepare(PatternDefinitionField &$field, array &$fieldArray) {
  }

  /**
   * {@inheritdoc}
   */
  public function get(Element $entity, string &$result = '') {
    $data = $this->elementHandler->serialize($entity);
    $stringData = [];
    foreach ($data as $item) {
      $stringData[] = $item['alt'];
    }
    return implode(' ', $stringData);
  }

  /**
   * {@inheritdoc}
   */
  public function getContent(Element $entity, array &$list = [], $published = TRUE) {
  }

  /**
   * {@inheritdoc}
   */
  public function serialize(Element $entity, array &$result = []) {
    $data = [];
    if ($entity->children) {
      foreach ($entity->children as $item) {
        if ($item->entity != NULL) {
          $medium = MediaFieldHandlerBase::getMediaTranslation($item->entity->field_media->entity);
          if ($medium != NULL && $medium->field_media_image->entity != NULL) {
            $file = $medium->field_media_image->entity;
            $urlGenerator = \Drupal::service('file_url_generator');
            $url = $previewUrl = $file->createFileUrl(FALSE);
            $style = \Drupal::entityTypeManager()
              ->getStorage('image_style')
              ->load('pagedesigner_default');
            if ($style != NULL) {
              $url = $previewUrl = $urlGenerator->transformRelative($style->buildUrl($file->getFileUri()));
            }
            $style = \Drupal::entityTypeManager()
              ->getStorage('image_style')
              ->load('thumbnail');
            if ($style != NULL) {
              $previewUrl = $urlGenerator->transformRelative($style->buildUrl($file->getFileUri()));
            }

            $data[] = [
              'alt' => $item->entity->field_content->value,
              'id' => $item->entity->field_media->target_id,
              'src' => $url,
              'preview' => $previewUrl,
              'uri' => $file->getFileUri(),
            ];
          }
        }
      }
    }
    $result = $data + $result;
  }

  /**
   * {@inheritdoc}
   */
  public function describe(Element $entity, array &$result = []) {
  }

  /**
   * {@inheritdoc}
   */
  public function generate($definition, array $data, Element &$entity = NULL) {
  }

  /**
   * {@inheritdoc}
   */
  public function patch(Element $entity, array $data) {
  }

  /**
   * {@inheritdoc}
   */
  public function copy(Element $entity, Element $container = NULL, Element &$clone = NULL) {
  }

  /**
   * {@inheritdoc}
   */
  public function delete(Element $entity, bool $remove = FALSE) {
  }

  /**
   * {@inheritdoc}
   */
  public function restore(Element $entity) {
  }

  /**
   * {@inheritdoc}
   */
  public function render(Element $entity, array &$build = []) {
  }

  /**
   * {@inheritdoc}
   */
  public function renderForPublic(Element $entity, array &$build = []) {
  }

  /**
   * {@inheritdoc}
   */
  public function renderForEdit(Element $entity, array &$build = []) {
  }

  /**
   * {@inheritdoc}
   */
  public function publish(Element $entity) {
  }

  /**
   * {@inheritdoc}
   */
  public function unpublish(Element $entity) {
  }

}
